@@ -1,6 +1,5 @@
 import os
 import warnings
-from pathlib import Path
 
 import fsspec
 import pandas as pd
@@ -121,6 +120,7 @@ class BaseRepository:
                 domain.Project(**json.loads(metadata))
                 for metadata in self._cat_paths(project_metadata_paths)
             ]
+            projects.sort(key=lambda p: p.created_at)
         except FileNotFoundError:
             return []
 
@@ -208,6 +208,7 @@ class BaseRepository:
                 domain.Experiment(**json.loads(metadata))
                 for metadata in self._cat_paths(experiment_metadata_paths)
             ]
+            experiments.sort(key=lambda e: e.created_at)
         except FileNotFoundError:
             return []
 
@@ -422,7 +423,7 @@ class BaseRepository:
         would leverage dask for large dataframes.
         """
         if isinstance(df, pd.DataFrame):
-            Path(path).mkdir(parents=True, exist_ok=True)
+            self.filesystem.mkdir(path, parents=True, exist_ok=True)
             path = f"{path}/data.parquet"
 
         df.to_parquet(path, engine="pyarrow")
@@ -529,6 +530,7 @@ class BaseRepository:
                 domain.Dataframe(**json.loads(metadata))
                 for metadata in self._cat_paths(dataframe_metadata_paths)
             ]
+            dataframes.sort(key=lambda d: d.created_at)
         except FileNotFoundError:
             return []
 
@@ -692,6 +694,7 @@ class BaseRepository:
                 domain.Feature(**json.loads(metadata))
                 for metadata in self._cat_paths(feature_metadata_paths)
             ]
+            features.sort(key=lambda f: f.created_at)
         except FileNotFoundError:
             return []
 
@@ -797,6 +800,7 @@ class BaseRepository:
                 domain.Metric(**json.loads(metadata))
                 for metadata in self._cat_paths(metric_metadata_paths)
             ]
+            metrics.sort(key=lambda m: m.created_at)
         except FileNotFoundError:
             return []
 
@@ -901,6 +905,7 @@ class BaseRepository:
                 domain.Parameter(**json.loads(metadata))
                 for metadata in self._cat_paths(parameter_metadata_paths)
             ]
+            parameters.sort(key=lambda p: p.created_at)
         except FileNotFoundError:
             return []
 
